@@ -1,7 +1,7 @@
 #ifndef _GTKMM_CONFIG_H
 #define _GTKMM_CONFIG_H
 
-#include <gdkmmconfig.h>
+#include <gskmmconfig.h>
 
 /* Define to omit deprecated API from gtkmm. */
 /* #undef GTKMM_DISABLE_DEPRECATED */
@@ -10,7 +10,7 @@
 #define GTKMM_MAJOR_VERSION 4
 
 /* Minor version number of gtkmm. */
-#define GTKMM_MINOR_VERSION 18
+#define GTKMM_MINOR_VERSION 20
 
 /* Micro version number of gtkmm. */
 #define GTKMM_MICRO_VERSION 0
@@ -24,7 +24,7 @@
 #endif
 
 #ifdef GTKMM_DLL
-# if defined (GDKMM_BUILD) || defined(GTKMM_BUILD)
+# if defined(GDKMM_BUILD) || defined(GSKMM_BUILD) || defined(GTKMM_BUILD)
 #  define GTKMM_API __declspec(dllexport)
 # elif !defined (__GNUC__)
 #  define GTKMM_API __declspec(dllimport)
